// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KEXIV2_VERSION_H
#define KEXIV2_VERSION_H

#define KEXIV2_VERSION_STRING "5.1.0"
#define KEXIV2_VERSION_MAJOR 5
#define KEXIV2_VERSION_MINOR 1
#define KEXIV2_VERSION_PATCH 0
#define KEXIV2_VERSION ((5<<16)|(1<<8)|(0))

#endif
